diff src/dnsbl.h @ 326:5e4b5540c8cc

allow multiple dkim signers in authentication results
author Carl Byington <carl@five-ten-sg.com>
date Sun, 18 Dec 2016 16:51:33 -0800
parents 9f8411f3919c
children f4ca91f49cb6
line wrap: on
line diff
--- a/src/dnsbl.h	Sat Dec 17 21:59:23 2016 -0800
+++ b/src/dnsbl.h	Sun Dec 18 16:51:33 2016 -0800
@@ -42,7 +42,7 @@
     const char      *fromaddr;              // header from value, set by mlfi_header()
     int             header_count;           // count of headers already seen
     bool            dkim_ok;                // ok to proceed with dkim checking
-    const char      *dkim_signer;           // non null if message was validly signed
+    string_set      dkim_signers;           // non empty if message was validly signed, set of signers
     const char      *queueid;               // sendmail queue id
     const char      *authenticated;         // client authenticated? if so, suppress all dnsbl checks, but check rate limits
     const char      *client_name;           // fully qualified host name of the smtp client xxx [ip.ad.dr.es] (may be forged)